Owner

You must enter an Certificate owner

Roles
Common Name

Either common name or subject alternate name(s) are required, and they must be less than 64 characters

Subject Alternate Names

{{ alt.nameType }} | {{ alt.value }} |

Description

You must give a short description about this certificate will be used for.

Certificate Authority
{{$select.selected.name}}
Note:
The selected authority uses the ACME protocol and works differently than other authorities. Your request will initially be created under the "pending certificates" section. Lemur will attempt to create the certificate for you, and move the final certificate to the "certificates" section. Lemur performs validation by writing a DNS text record. You may choose a specific DNS provider, or allow Lemur to automatically detect the correct provider for you. Requests may take up to ten minutes.
DNS Provider:
Validity Range
Default ({{certificate.authority.defaultValidityDays}} days) Custom
Validity Range
Certificates for LetsEncrypt expire 90 days after creation. Enable auto-rotate to have Lemur automatically rotate the certificate and update your endpoints.
Auto Rotate